@@ -130,14 +130,16 @@ class LMContext(BaseContext):
     game = "Luigi's Mansion"
     items_handling = 0b111
 
-    def __init__(self, server_address, password, slot_name: str = None, ready_callback=None, error_callback=None):
+    def __init__(self, server_address, password, ready_callback=None, error_callback=None):
         super().__init__(server_address, password)
         self.ready_callback = ready_callback
         self.error_callback = error_callback
-        self.slot_name = slot_name
+        
         # Handle various Dolphin connection related tasks
         self.instance_id = None
         self.dolphin_sync_task: Optional[asyncio.Task[None]] = None
+        self.rom_loaded = False
+        self.password_required = False
         self.dolphin_status = CONNECTION_INITIAL_STATUS
         self.item_display_queue: list[NetUtils.NetworkItem] = []
 
@@ -199,22 +201,7 @@ class LMContext(BaseContext):
         dme.un_hook()
         self.dolphin_status = CONNECTION_LOST_STATUS
         self.already_fired_events = False
-
-    async def server_auth(self, password_requested: bool = False):
-        """
-        Authenticate with the Archipelago server.
-
-        :param password_requested: Whether the server requires a password. Defaults to `False`.
-        """
-        if password_requested and not self.password:
-            await super(LMContext, self).server_auth(password_requested)
-        if not self.auth:
-            return
-        await self.send_connect()
-
-        if self.slot:
-            logger.info(CONNECTION_CONNECTED_STATUS)
-            self.dolphin_status = CONNECTION_CONNECTED_STATUS
+        self.rom_loaded = False
 
     def on_package(self, cmd: str, args: dict):
         """
@@ -269,12 +256,36 @@ class LMContext(BaseContext):
                     self.instance_id = time.time()
                 self.trap_link.on_bounced(args, self.get_item_count_by_id(8148))
                 self.ring_link.on_bounced(args)
+
             case "SetReply":
                 if not (self.check_ingame() and self.check_alive()):
                     return
 
                 self.energy_link.try_update_energy_request(args)
 
+            case "ConnectionRefused":
+                self.dolphin_status = AP_REFUSED_STATUS
+                logger.error(self.dolphin_status)
+
+            case "RoomInfo":
+                self.password_required = bool(args['password'])
+
+    async def server_auth(self, password_requested: bool = False):
+        """
+        Authenticate with the Archipelago server. This function will be called as part of the init RoomInfo call
+        in CommonClient, however we will exit if the rom is not loaded yet.
+
+        :param password_requested: Whether the server requires a password. Defaults to `False`.
+        """
+        if not self.rom_loaded:
+            logger.info("ROM is not loaded yet, waiting for dolphin to be connected before trying again.")
+            return
+
+        if password_requested and not self.password:
+            logger.info('Enter the password required to join this game:')
+            self.password = await self.console_input()
+        await self.send_connect()
+
     def on_deathlink(self, data: dict[str, Any]):
         """
         Handle a DeathLink event.
@@ -866,10 +877,11 @@ class LMContext(BaseContext):
                         self.locations_checked = set()
 
                         # Inform the player we are ready and waiting for them to connect.
-                        if not self.dolphin_status == CONNECTION_VERIFY_SERVER:
+                        if not self.rom_loaded:
                             self.dolphin_status = CONNECTION_VERIFY_SERVER
                             logger.info(self.dolphin_status)
-                        await self.server_auth()
+                            self.rom_loaded = True
+                            await self.server_auth(self.password_required)
 
                         if not self.slot:
                             await self.wait_for_next_loop(WAIT_TIMER_LONG_TIMEOUT)
@@ -881,7 +893,10 @@ class LMContext(BaseContext):
                                 "Incorrect Randomized Luigi's Mansion ISO file selected. The seed does not match." +
                                 "Please verify that you are using the right ISO/seed/APLM file.")
 
-                    # At this point, we are verified as connected. Update UI elements in the LMCLient screen.
+                        logger.info(CONNECTION_CONNECTED_STATUS)
+                        self.dolphin_status = CONNECTION_CONNECTED_STATUS
+
+                    # At this point, we are verified as connected. Update UI elements in the LMCLient tab.
                     if self.ui:
                         boo_count = len(
                             set(([item.item for item in self.items_received if item.item in BOO_AP_ID_LIST])))
@@ -919,7 +934,7 @@ def main(*launch_args: str):
     server_address: str = ""
     rom_path: str = ""
 
-def launch(server_address: str = None, password: str = None, slot_name: str = None, ready_callback=None, error_callback=None, output_data: str = None):
+def launch(server_address: str = None, ready_callback=None, error_callback=None, output_data: str = None):
     """
     Launch the client
     """
@@ -942,7 +957,7 @@ def launch(server_address: str = None, password: str = None, slot_name: str = No
                     error_callback()
                 return
 
-        ctx = LMContext(actual_server_address, password, slot_name, ready_callback, error_callback)
+        ctx = LMContext(actual_server_address, ready_callback, error_callback)
         if ctx._can_takeover_existing_gui():
             await ctx._takeover_existing_gui() 
         else:
@@ -951,6 +966,7 @@ def launch(server_address: str = None, password: str = None, slot_name: str = No
                 error_callback()
             return
 
+        apname = Utils.instance_name if Utils.instance_name else "Archipelago"
         ctx.ui.base_title = apname + " | Luigi's Mansion"
         ctx.server_task = asyncio.create_task(server_loop(ctx), name="ServerLoop")
         await ctx.server_auth()
@@ -988,9 +1004,9 @@ def launch(server_address: str = None, password: str = None, slot_name: str = No
             error_callback()
 
 
-def main(server_address: str = None, password: str = None, slot_name: str = None, ready_callback=None, error_callback=None, output_data: str = None):
+def main(server_address: str = None, password: str = None, ready_callback=None, error_callback=None, output_data: str = None):
     """Main entry point for integration with MultiWorld system"""
-    launch(server_address, password, slot_name, ready_callback, error_callback, output_data)
+    launch(server_address, password, ready_callback, error_callback, output_data)
 
 if __name__ == "__main__":
     parser = get_base_parser()
